@@ -1,11 +1,30 @@
-/* -*- Mode: C; c-basic-offset: 4 -*- */
+/* -*- Mode: C; c-basic-offset: 4 -*-
+ * pygtk- Python bindings for the GTK toolkit.
+ * Copyright (C) 1998-2003  James Henstridge
+ *
+ *   pygtktreemodel.c: stub class to help implement tree models.
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Lesser General Public
+ * License as published by the Free Software Foundation; either
+ * version 2.1 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Lesser General Public License for more details.
+ *
+ * You should have received a copy of the GNU Lesser General Public
+ * License along with this library; if not, write to the Free Software
+ * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * USA
+ */
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
 
 #include "pygtktreemodel.h"
 #include <Python.h>
-#include "pygobject.h"
 #include "pygtk-private.h"
 
 /* define this to print out debug messages */
@@ -209,7 +228,6 @@ pygtk_generic_tree_model_get_flags(GtkTreeModel *tree_model)
 	return ret;
     } else {
 	PyErr_Print();
-	PyErr_Clear();
 	pyg_unblock_threads();
 	return 0;
     }
@@ -240,7 +258,6 @@ pygtk_generic_tree_model_get_n_columns(GtkTreeModel *tree_model)
 	return ret;
     } else {
 	PyErr_Print();
-	PyErr_Clear();
 	pyg_unblock_threads();
 	return 0;
     }
@@ -271,7 +288,6 @@ pygtk_generic_tree_model_get_column_type(GtkTreeModel *tree_model, gint index)
 	return ret;
     } else {
 	PyErr_Print();
-	PyErr_Clear();
 	pyg_unblock_threads();
 	return G_TYPE_INVALID;
     }
@@ -317,7 +333,6 @@ pygtk_generic_tree_model_get_iter(GtkTreeModel *tree_model,
 	}
     } else {
 	PyErr_Print();
-	PyErr_Clear();
 	iter->user_data = NULL;
 	pyg_unblock_threads();
 	return FALSE;
@@ -352,7 +367,6 @@ pygtk_generic_tree_model_get_path(GtkTreeModel *tree_model, GtkTreeIter *iter)
 	return path;
     } else {
 	PyErr_Print();
-	PyErr_Clear();
 	pyg_unblock_threads();
 	return NULL;
     }
@@ -388,7 +402,6 @@ pygtk_generic_tree_model_get_value(GtkTreeModel*tree_model, GtkTreeIter *iter,
 	Py_DECREF(py_value);
     } else {
 	PyErr_Print();
-	PyErr_Clear();
     }
     pyg_unblock_threads();
 }
@@ -430,7 +443,6 @@ pygtk_generic_tree_model_iter_next(GtkTreeModel *tree_model, GtkTreeIter *iter)
     } else {
 	iter->user_data = NULL;
 	PyErr_Print();
-	PyErr_Clear();
 	pyg_unblock_threads();
 	return FALSE;
     }
@@ -476,7 +488,6 @@ pygtk_generic_tree_model_iter_children(GtkTreeModel *tree_model, GtkTreeIter *it
     } else {
 	iter->user_data = NULL;
 	PyErr_Print();
-	PyErr_Clear();
 	pyg_unblock_threads();
 	return FALSE;
     }
@@ -509,7 +520,6 @@ pygtk_generic_tree_model_iter_has_child(GtkTreeModel *tree_model, GtkTreeIter *i
 	return ret;
     } else {
 	PyErr_Print();
-	PyErr_Clear();
 	pyg_unblock_threads();
 	return FALSE;
     }
@@ -542,7 +552,6 @@ pygtk_generic_tree_model_iter_n_children(GtkTreeModel *tree_model, GtkTreeIter *
 	return ret;
     } else {
 	PyErr_Print();
-	PyErr_Clear();
 	pyg_unblock_threads();
 	return 0;
     }
@@ -588,7 +597,6 @@ pygtk_generic_tree_model_iter_nth_child(GtkTreeModel *tree_model, GtkTreeIter  *
     } else {
 	iter->user_data = NULL;
 	PyErr_Print();
-	PyErr_Clear();
 	pyg_unblock_threads();
 	return FALSE;
     }
@@ -634,7 +642,6 @@ pygtk_generic_tree_model_iter_parent(GtkTreeModel *tree_model, GtkTreeIter *iter
     } else {
 	iter->user_data = NULL;
 	PyErr_Print();
-	PyErr_Clear();
 	pyg_unblock_threads();
 	return FALSE;
     }
